import type { DateRange } from '../dateRange'
import type { EntryTagCollection } from '../entryTag'
import type { EntryWithConfig, EntryWithContent } from './shared'

/**
 * This describes aditional information about a project.
 * to display when listing the project on the portfolio page.
 * At minimum, the title should be specified.
 */
export type ProjectListingInfo = {
  date?: DateRange | string | number
  /**[Supports Markdown]
   * Information to summarize a project
   */
  description?: string
  /**
   * Tags that correspond to project filters on the portfolio page if defined
   */
  tags?: string[]
  /**[Supports Markdown]
   * The title of the project
   */
  title: string
  thumbnail?: {
    style: CSSStyleDeclaration
  }
}

export type ProjectEntries = { [key: string]:
  & EntryWithContent
  & EntryWithConfig<ProjectListingInfo>
}

export type ProjectList = {
  projects: ProjectEntries
  tags?: EntryTagCollection
  removeFromView?: boolean
}
